<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-page-header style="width: 20%;margin-right: 20px;" @back="goBack" :content="product.typeName">
      </el-page-header>
      <el-form v-model="queryParam" :inline="true">
        <!-- <el-form-item label="产品">
          <el-cascader v-model="productValue" :options="productData" :show-all-levels="false" @change="delProduct"
            :props="{  label: 'name', value: 'id',children: 'children',checkStrictly: true }" clearable>
          </el-cascader>
        </el-form-item> -->
        <el-form-item label="设备名称">
          <el-input maxlength="64" clearable placeholder="请输入设备名称" v-model="params.name"></el-input>
        </el-form-item>
        <el-form-item label="区域">
          <el-cascader v-model="regionValue" :options="treeData" :show-all-levels="false" @change="delRegion"
                       :props="{  label: 'name', value: 'id',children: 'children',checkStrictly: true }" clearable>
          </el-cascader>
        </el-form-item>
        <el-form-item label="设备状态">
          <el-select v-model="params.status" clearable placeholder="请选择设备类型">
            <el-option v-for="item in deviceStatus" :key="item.value" :label="item.name"
                       :value="item.value"></el-option>
          </el-select>
        </el-form-item>

        <el-form-item>
          <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索</el-button>
          <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
          <el-button type="text" @click.stop="openMore">更多
            <i :class="
							showMore ? 'el-icon-arrow-up' : 'el-icon-arrow-down'
						  "></i>
          </el-button>
        </el-form-item>
        <div class="bbsl-search-more" style="width: 320px; height: 60px" v-if="showMore">
          <el-row>
            <el-col :span="24">
              <el-form-item label="重点设备">
                <el-select v-model="params.important" clearable placeholder="是否是重点设备">
                  <el-option label="一般设备" value="0"></el-option>
                  <el-option label="重点设备" value="1"></el-option>
                </el-select>
              </el-form-item>
            </el-col>
          </el-row>
        </div>
      </el-form>
    </div>

    <div class="bbsl-table-content" ref="contentPanel">
      <div class="bbsl-btn-content" ref="btnPanel" style="display: flex;">
        <div class="statistics">
          <div class="item">
            <el-badge is-dot type="primary"></el-badge>
            <span class="all-device">全部设备<span>{{ deviceInfo.allNum || 0 }}</span></span>
          </div>

          <div class="item">
            <el-badge is-dot type="success"></el-badge>
            <span class="all-device">正常<span>{{ deviceInfo.normalNum || 0 }}</span></span>
          </div>
          <div class="item">
            <el-badge is-dot type="danger"></el-badge>
            <span class="all-device">报警：{{ deviceInfo.warnNum || 0 }}</span>
          </div>
          <div class="item">
            <el-badge is-dot type="warning"></el-badge>
            <span class="all-device">故障<span>{{ deviceInfo.failureNum || 0 }}</span></span>
          </div>
          <i @click="refreshInfo" class="el-icon-refresh refresh"></i>
        </div>
      </div>
      <el-table border size="mini" v-loading="loading" ref="multipleSelection" :data="tableData"
                :style="{width: '100%'}" :max-height="tableMaxHeight" :cell-style="{'text-align': 'center'}"
                :header-cell-style="{'text-align': 'center'}" @row-dblclick="toEquipmentDetails"
                @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55"></el-table-column>
        <el-table-column fixed type="index" width="55" label="序号"></el-table-column>
        <el-table-column sortable prop="productName" label="产品名称" show-overflow-tooltip></el-table-column>
        <el-table-column fixed min-width="150" sortable prop="name" label="设备名称" show-overflow-tooltip>
        </el-table-column>
        <el-table-column sortable prop="code" label="设备标识" show-overflow-tooltip></el-table-column>

        <el-table-column sortable prop="areaName" label="所属区域" show-overflow-tooltip></el-table-column>
        <el-table-column sortable prop="lgtd" label="经度" show-overflow-tooltip></el-table-column>
        <el-table-column sortable prop="lttd" label="纬度" show-overflow-tooltip></el-table-column>
        <el-table-column sortable min-width="90" prop="life" label="使用年限" show-overflow-tooltip>
        </el-table-column>
        <el-table-column sortable min-width="150" prop="important" label="是否是重点设备" show-overflow-tooltip>
          <template slot-scope="scope">
            <span v-if="scope.row.important == '1'">重点设备</span>
            <span v-else-if="scope.row.important == '0'">一般设备</span>
          </template>
        </el-table-column>
        <el-table-column sortable prop="statusName" label="设备状态" show-overflow-tooltip>
          <template slot-scope="scope">
            <div :style="
                scope.row.status == '-1'
                  ? {color: '#409EFF'}
                  : scope.row.status == '1'
                  ? {color: '#13ce66'}
                  : scope.row.status == '2'
                  ? {color: '#ff4949'}
                  : {color: '#e6a23c'}
              ">
              {{ scope.row.statusName }}
            </div>
          </template>
        </el-table-column>
        <!-- <el-table-column
          sortable
          prop="flag"
          label="禁用状态"
          min-width="70"
          show-overflow-tooltip
        >
          <template slot-scope="scope">
            <el-switch
              v-model="scope.row.flag"
              active-color="#13ce66"
              @change="handleFlag(scope.row)"
              inactive-color="#ff4949"
              :active-value="1"
              :inactive-value="0"
            >
            </el-switch>
          </template>
        </el-table-column> -->
        <!-- <el-table-column min-width="130" label="操作" fixed="right">
          <template #default="scope">
            <el-dropdown trigger="click" split-button>
              <i class="el-icon-setting" style="margin-right:5px"></i>
              管理按钮
              <el-dropdown-menu slot="dropdown">
                <el-dropdown-item @click.native="revise(scope.row)">
                  <i class="el-icon-edit-outline"></i> 修改设备状态
                </el-dropdown-item>
                <el-dropdown-item @click.native="equipment(scope.row)" v-if="scope.row.important">
                  <i class="el-icon-edit-outline"></i> {{scope.row.important==0?'修改重点设备':scope.row.important==1?'修改一般设备':''}}
                </el-dropdown-item>
              </el-dropdown-menu>
            </el-dropdown>
          </template>
        </el-table-column> -->
      </el-table>
      <el-pagination align="right" background class="bbsl-pagination" ref="paginationPanel"
                     @size-change="handleSizeChange" @current-change="handleCurrentChange"
                     :current-page="queryParam.pageBean.page" :page-sizes="[20, 30, 40, 50]"
                     :page-size="queryParam.pageBean.pageSize" layout="total, sizes, prev, pager, next, jumper"
                     :total="total"></el-pagination>
    </div>


  </div>
</template>

<script>
import {
  mapState
} from 'vuex'
import {
  TableMixin
} from '@/mixins/tableMixin'
// import EquipmentManageDialog from '@/views/Device/deviceManage/components/EquipmentManageDialog'
// import EquipmentExtendDialog from '@/views/Device/deviceManage/components/EquipmentExtendDialog'
import resourceManage from '@/api/device/resourceManage.js'
import userManage from '@/api/device/userManage.js'
import equipmentManage from '@/api/device/equipmentManage.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'

export default {
  name: 'EquipmentManage',
  components: {
    // EquipmentManageDialog,
    // EquipmentExtendDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      importVisible: false,
      reviseDat: '',
      reviseVisible: false,
      reviseStart: '',
      exportParam: {},
      //携带参数
      uploadData: {
        productId: ''
      },
      url: {
        delete: '/device/info/'
      },
      treeData: [],
      productValue: [],
      regionValue: [],
      showMore: false,
      parameters: {},
      showExtend: false,
      params: {
        name: '',
        productId: '', //产品
        status: '', //状态
        important: '', //重点设备
        areaId: '' //区域
      },
      querys: [{
        group: 'main',
        operation: 'LIKE',
        parentGroup: '',
        property: 'd.name_',
        relation: 'AND',
        value: ''
      },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'product_id_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'status',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'd.code_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'important',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'areaId',
          relation: 'AND',
          value: ''
        }


      ],
      deviceStatus: [], // 设备状态
      productData: [], // 产品数据
      flagList: [], //禁用标识字段列表
      addressTypeList: [], //安装地点类型字段列表
      productIdInfo: '',
      deviceInfo: {
        0: '',
        1: '',
        2: '',
        3: '',
        9: '',
        10: ''
      }, //设备状态数量
      product: {}
    }
  },
  //获取token
  computed: mapState({
    header: state => {
      return {
        Authorization: `Bearer ${state.login.currentUser.token}`
      }
    }
  }),
  created() {
    //在created里面区获取actionUrl
    this.product = JSON.parse(localStorage.getItem('product'))
    console.log(this.product)
    this.params.productId = this.product.typeId
    this.actionUrl = window.context.portal
    this.getDeviceInfo()
    this.getAreaTree()
  },
  mounted() {
    this.deviceStatus = dictUtils.getDictItemsFromCache('sbzt')
    this.flagList = dictUtils.getDictItemsFromCache('jybs')
    this.addressTypeList = dictUtils.getDictItemsFromCache('azddlx')
  },
  methods: {
    goBack() {
      this.$router.go(-1)
      // this.$router.push({
      // 	path: 'DeviceAnalysis'
      // })
    },
    delRegion() {
      if (this.regionValue.length == 0) {
        this.params.areaId = ''
      }
    },

    openMore() {
      this.showMore = !this.showMore
    },
    getAreaTree() {
      equipmentManage.loadAreaTree({
        id: '0'
      }, res => {
        this.treeData = res.value // this.formatData(res.rows)
        this.$set(this.treeData)
      })
    },
    handleClose() {
      this.importVisible = false
      this.reviseVisible = false
    },
    toEquipmentDetails(val) {
      let path = this.$route.path
      if (path.indexOf('frontPlat') !== -1) {
        this.$router.push({
          name: 'EquipmentDetails',
          query: {
            id: val.id,
            name: val.name,
            status: false
          }
        })
      } else {
        this.$router.push({
          name: 'EquipmentDetailsLink',
          query: {
            id: val.id,
            name: val.name,
            status: false
          }
        })
      }
    },

    // 点击刷新设备数量
    refreshInfo() {
      this.getDeviceInfo()
    },
    // 根据产品id获取设备数量
    getDeviceInfo() {
      let data = {
        productId: this.params.productId
      }
      equipmentManage.getDeviceInfo(this.qs.stringify(data), res => {
        this.deviceInfo = res.value
      })
    },
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true

      if (this.regionValue.length > 0) {
        let arr = JSON.parse(JSON.stringify(this.regionValue))
        this.params.areaId = arr.pop()
      }
      this.queryParam.params = this.params
      this.tableData = []
      resourceManage.loadDevice(this.queryParam, res => {
        this.total = res.total
        this.tableData = res.rows
        this.$set(this.tableData)
        this.loading = false
        this.tableData.forEach(item => {
          this.deviceStatus.forEach(val => {
            if (item.status == val.value) {
              item['statusName'] = val.name
            }
          })
          this.addressTypeList.forEach(val => {
            if (item.addressType == val.value) {
              item['addressTypeName'] = val.name
            }
          })
        })
      })
      if (this.querys[1].value == '') {
      }
    }
  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}

.refresh:hover {
  cursor: pointer;
}

.refresh {
  font-size: 28px;
  line-height: inherit;
}

::v-deep .el-badge {
  height: 10px;
  position: relative;
  vertical-align: sub;
  display: inline-block;
}

.all-device {
  font-size: 20px;
  padding-left: 5px;
}

.all-device > span {
  font-size: 20px;
  padding-left: 10px;
}

.touchBox {
  position: absolute;
  width: auto;
  border-radius: 10px;
  z-index: 10000;
  padding: 8px 12px;
  box-sizing: border-box;
  background: #242846;
  display: flex;
  justify-content: center;
  flex-direction: column;
  color: #fff;
  display: none;

  .touch-item {
    width: 120px;
  }


}

.statistics {
  flex: 1;
  display: flex;
  justify-content: space-evenly;
  margin-left: 20px;

  .item {
    display: flex;
    align-items: center;

    .icon {
      display: inline-block;
      width: 8px;
      height: 8px;
      margin-right: 6px;
      border-radius: 100%;

      &.color1 {
        background: rgb(19, 206, 102);
      }

      &.color2 {
        background: rgb(230, 162, 60);
      }

      &.color3 {
        background: #4275e8;
      }

      &.color4 {
        background: rgb(255, 73, 73);
      }
    }
  }
}

.onlineItem {
  &:hover {
    .touchBox {
      display: block;
    }
  }
}

.malfunction {
  &:hover {
    .touchBox {
      display: block;
    }
  }
}

a {
  color: #fff;
}
</style>
<style lang="scss">
.scorll {
  .el-scrollbar__wrap {
    overflow: scroll;
    height: 100%;
  }
}

.bbsl-table-search {
  cursor: pointer;
}
</style>
